@@ -1,17 +1,11 @@
-import asyncio
-import gzip
-import io
-import json
 import logging
-
 import time
-
 import socketio
 import ubjson
-import ujson as ujson
 from multiprocessing.dummy import Pool
 
 
+
 class GSCNodeFunctionReceiverSocket:
     @classmethod
     def create(cls, sio, gsdbs, oncnodefunction, poolsize):
@@ -32,7 +26,7 @@ class GSCNodeFunctionReceiverSocket:
             # self._logger.info('cnodefunction succeed')
 
         def on_errorPost(error):
-            self._logger.exception('cnodefunction failed : ' + str(error))
+            self._logger.exception('cnodefunction failed :' + error)
 
         @self.sio.event
         def oncnodefunction(id, msg):
@@ -53,7 +47,7 @@ class GSCNodeFunctionReceiverSocket:
         self.sio.wait()
 
     def sendcnodefunctionResult(self, id, msg):
-        self.sio.emit("answer", id, msg)
+        self.sio.emit("cnodeanswer", id, msg)
 
 
 class GSCNodeFunctionReceiver:
@@ -67,7 +61,8 @@ class GSCNodeFunctionReceiver:
         GSCNodeFunctionReceiverSocket.create(self.sio, self.gsdbs, self.oncnodefunction, self.poolsize)
 
     def sendcnodefunctionanswer(self, id, msg):
-        self.sio.emit("answer", {"id": id, "message": ujson.dumps(msg)})
+        encoded = ubjson.dumpb(msg)
+        self.sio.emit("cnodeanswer", {"id": id, "data": encoded})
 
 
 class GSCNodeFunctionCallerSocket:
@@ -84,11 +79,11 @@ class GSCNodeFunctionCallerSocket:
             self._logger.info('oncnodefunction connected')
 
         @self.sio.event
-        def answer(id, message):
+        def cnodeanswer(id, message):
             if (type(message) is dict):
                 self.oncnodefunctionanswer(self.gsdbs, message)
             else:
-                self.oncnodefunctionanswer(self.gsdbs, ujson.loads(message))
+                self.oncnodefunctionanswer(self.gsdbs, ubjson.loadb(message))
 
         connectURL = ""
 
@@ -111,7 +106,9 @@ class GSCNodeFunctionCaller:
         self._logger = logging.getLogger(__name__)
 
     def startSocket(self):
-        GSCNodeFunctionCallerSocket.create(self.sio, self.gsdbs, self.oncnodefunctionanswer)
+        GSCNodeFunctionCallerSocket.create(self.sio,
+                                           self.gsdbs,
+                                           self.oncnodefunctionanswer)
 
     def on_success(self, r):
         self._logger.info('cnodefunction succeed')
@@ -123,10 +120,11 @@ class GSCNodeFunctionCaller:
         msg["cnodefunction"] = target
 
         encoded = ubjson.dumpb(msg)
-
         sio.emit("oncnodefunction", {"target": target, "data": encoded})
 
     def sendcnodefunction(self, target, msg):
         time.sleep(0.01)
-        self._pool.apply_async(self.emitFunction, args=[self.sio, target, msg], callback=self.on_success,
+        self._pool.apply_async(self.emitFunction,
+                               args=[self.sio, target, msg],
+                               callback=self.on_success,
                                error_callback=self.on_errorPost)
