@@ -160,6 +160,9 @@ class GSPeerConnectionBroadcasterPi:
                 await self.peerConnections[id].close()
                 self.peerConnections.pop(id, None)
 
+        @self.sio.event
+        async def candidate(id, candidate):
+            await self.peerConnections[id].addIceCandidate()
 
         @self.sio.event
         async def disconnect():
